<?php
global $monthname;
$monthname = ['?',
	'januari', 'februari', 'maart', 'april', 'mei', 'juni',
	'juli', 'augustus', 'september', 'oktober', 'november', 'december',
];

function showdate($parts)
{
	global $monthname;
	return implode(' ', array_filter([
		intval(@$parts[2]), $parts[1] > 0 ? $monthname[intval($parts[1])] : '', $parts[0],
		count($parts) > 5 ? "$parts[3]:$parts[4]" : '',
	]));
}

class ArchiveArticle
{
	public $raw, $preface, $title, $body;

	function __construct($path)
	{
		$this->page = $path;
		$this->link = preg_replace('{(?:/index)?\.html$}', '', $path);
		if (file_exists($this->page)) {
			$this->raw = file_get_contents($this->page);
			@list ($this->preface, $this->title, $this->body) =
				preg_split('{<h2>(.*?)</h2>\s*}', $this->raw, 2, PREG_SPLIT_DELIM_CAPTURE);
		}
	}

	function __get($col)
	{
		return $this->$col = $this->$col();  # run method and cache
	}

	function safetitle()
	{
		return trim(strip_tags($this->title));
	}
	function name()
	{
		return $this->safetitle ?: $this->link;
	}

	function last()
	{
		return filemtime($this->page);
	}
	function lastiso()
	{
		return date(DATE_ATOM, $this->last);
	}

	function dateparts()
	{
		preg_match('< / (\d{4}) [/-] (\d{2}) (?:- (\d{2}) )? - >x', $this->page, $ymd);
		array_shift($ymd);
		return $ymd;
	}
	function dateiso()
	{
		return implode('-', $this->dateparts()) . 'T12:00:00+02:00';
	}
	function date()
	{
		return showdate($this->dateparts);
	}

	function story()
	{
		if ( preg_match('{
			\n (?: < (?: p | figure [^>]* ) >\s* )+ (<img\ [^>]*>) | \n <hr\ />
		}x', $this->body, $img, PREG_OFFSET_CAPTURE) ) {
			# strip part after matching divider (image)
			if (isset($img[1])) {
				$this->img = $img[1][0];
			}
			return substr($this->body, 0, $img[0][1]);
		}
		return $this->body;
	}
	function teaser()
	{
		if (preg_match('{
			<meta \s+ name="description" [^>]* content="([^">]*)"
		}x', $this->preface, $meta)) {
			# prefer specific page description if found (assume before title)
			#TODO: strip from body contents
			return $meta[1];
		}
		if (preg_match('{
			</h2> (?: \s+ | <p\sclass="nav\b.*?</p> | <div[^>]*> )* <p> (.*?) </p>
		}sx', $this->raw, $bodyp, PREG_OFFSET_CAPTURE)) {
			# fallback paragraph contents following the page header
			if ($bodyp[1][1] < 256) {
				return $bodyp[1][0];
			}
		}
	}

	function img()
	{
		$this->img = NULL;
		$this->story;
		return $this->img;
	}
	function image()
	{
		if ( preg_match('/\bsrc="([^"]*)"/', $this->img, $src) ) {
			return $src[1];
		}
	}
	function thumb($size = '300x')
	{
		if (!$this->image or $this->image[0] !== '/') return;
		return preg_replace(
			['{^(?:/thumb/[^/]*)?}', '/\.groot(?=\.\w+$)/'], ["thumb/$size", ''],
			$this->image
		);
	}
}
